# - Config file for the VecGeom package
# Defines the following variables
#   VECGEOM_FOUND        - Found the VECGEOM library
#   VECGEOM_INCLUDE_DIR  - include directories for VecGeom
#   VECGEOM_LIBRARIES    - libraries to link against
#   VECGEOM_DEFINITIONS - some core flags used to build the vecgeom library and which need to be reused 
#                               in projects using VecGeom 
#   VECGEOM_INSTALL_DIR     - the top level installation path
#   VECGEOM_EXTERNAL_INCLUDES - external include paths used during vecgeom compilation (for automatic "discovery" of dependencies)
#   VECGEOM_C_COMPILER      - the C compiler used to compile VecGeom
#   VECGEOM_CXX_COMPILER    - the CXX compiler used to compile VecGeom

if(NOT VecGeom_FIND_QUIETLY)
  message(STATUS
    "Using VecGeom install configuration at ${CMAKE_CURRENT_LIST_FILE}.")
endif()

get_filename_component(THIS_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)
set(VECGEOM_INCLUDE_DIR "${THIS_DIR}/../../../include")
set(VECGEOM_LIBRARIES "dl;${THIS_DIR}/../..//libvecgeom.a")
set(USOLIDS_LIBRARIES "dl;${THIS_DIR}/../..//libvecgeom.a")
set(VECGEOM_INSTALL_DIR "$ENV{VECGEOM_FQ_DIR}")
set(VECGEOM_COMPILE_OPTIONS  -msse3)
set(VECGEOM_CUDA_STATIC_LIBRARY "")

set(VECGEOM_DEFINITIONS   -DVECGEOM_SCALAR -DVECGEOM_QUADRILATERALS_VC -DVECGEOM_NO_SPECIALIZATION -DVECGEOM_INPLACE_TRANSFORMATIONS -DVECGEOM_USE_INDEXEDNAVSTATES)
add_definitions(${VECGEOM_DEFINITIONS})

# add the include directories used to compile VecGeom
set(VECGEOM_EXTERNAL_INCLUDES ";/Users/macdev/workspace/build-vg/QUAL/c7/label1/swarm/label2/OSX-10.14/build/veccore/v0_6_0/Darwin64bit+18-c7/include")
set(VECGEOM_INCLUDE_DIRS ${VECGEOM_EXTERNAL_INCLUDES} ${VECGEOM_INCLUDE_DIR})
set(USOLIDS_INCLUDE_DIRS ${VECGEOM_INCLUDE_DIRS})

set(VECGEOM_C_COMPILER "$ENV{GCC_FQ_DIR}/bin/clang")
set(VECGEOM_CXX_COMPILER "$ENV{GCC_FQ_DIR}/bin/clang++")
set(VECGEOM_CXX_FLAGS "${CMAKE_CXX_FLAGS}  -msse3")

set(VECGEOM_GEANT4 )
set(VECGEOM_CUDA_ARCH "")
set(VECGEOM_FOUND TRUE)

